==> jc-1.4.0.tar.gz: polyglot/frontend/InnerJob.h <==
// public class polyglot.frontend.InnerJob

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9297314e3af3ddba polyglot_frontend_InnerJob
// @dep_class 42e687805b457724 polyglot_frontend_Job

// header file dependencies
// @dep_header polyglot_frontend_Job

#include "polyglot/frontend/Job.h"

#ifndef _JC_polyglot_frontend_InnerJob_H_
#define _JC_polyglot_frontend_InnerJob_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_JobExt$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_frontend_SourceJob$object;
struct _jc_polyglot_types_Context$object;

// Typedefs
typedef struct _jc_polyglot_frontend_InnerJob$sub_refs	_jc_polyglot_frontend_InnerJob$sub_refs;
typedef struct _jc_polyglot_frontend_InnerJob$sub_nonrefs	_jc_polyglot_frontend_InnerJob$sub_nonrefs;
typedef struct _jc_polyglot_frontend_InnerJob$refs	_jc_polyglot_frontend_InnerJob$refs;
typedef struct _jc_polyglot_frontend_InnerJob$nonrefs	_jc_polyglot_frontend_InnerJob$nonrefs;
typedef struct _jc_polyglot_frontend_InnerJob$object	_jc_polyglot_frontend_InnerJob$object;

typedef const struct _jc_polyglot_frontend_InnerJob$vmethods	_jc_polyglot_frontend_InnerJob$vmethods;
typedef const struct _jc_polyglot_frontend_InnerJob$vtable	_jc_polyglot_frontend_InnerJob$vtable;
typedef const struct _jc_polyglot_frontend_InnerJob$vtype	_jc_polyglot_frontend_InnerJob$vtype;

// Constructors
extern void _jc_polyglot_frontend_InnerJob$method$_init$01920a4a6e363988(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Pass__24ID$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_frontend_InnerJob$method$context$4c5ebe4f0ff1c15f(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
extern struct _jc_object *_jc_polyglot_frontend_InnerJob$method$getPasses$e5b4184d264aa29f(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
extern struct _jc_polyglot_frontend_SourceJob$object *_jc_polyglot_frontend_InnerJob$method$sourceJob$2fc26d39f6f66cf4(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_InnerJob$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$context$4c5ebe4f0ff1c15f;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$getPasses$e5b4184d264aa29f;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$sourceJob$2fc26d39f6f66cf4;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_InnerJob$vmethods {
	struct _jc_object	*(*context$4c5ebe4f0ff1c15f)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
	struct _jc_object	*(*getPasses$e5b4184d264aa29f)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
	struct _jc_polyglot_frontend_SourceJob$object	*(*sourceJob$2fc26d39f6f66cf4)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *);
};

// Vtable
struct _jc_polyglot_frontend_InnerJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Job$vmethods	polyglot_frontend_Job;
	_jc_polyglot_frontend_InnerJob$vmethods	polyglot_frontend_InnerJob;
};

// Vtype
struct _jc_polyglot_frontend_InnerJob$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_InnerJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_InnerJob$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*outer;
	struct _jc_object	*context;
	struct _jc_polyglot_frontend_Pass__24ID$object	*begin;
	struct _jc_polyglot_frontend_Pass__24ID$object	*end;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_InnerJob$refs {
    _jc_polyglot_frontend_InnerJob$sub_refs	polyglot_frontend_InnerJob;
    _jc_polyglot_frontend_Job$sub_refs	polyglot_frontend_Job;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_InnerJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_InnerJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Job$sub_nonrefs	polyglot_frontend_Job;
    _jc_polyglot_frontend_InnerJob$sub_nonrefs	polyglot_frontend_InnerJob;
};

// Object instance structure
struct _jc_polyglot_frontend_InnerJob$object {
	_jc_polyglot_frontend_InnerJob$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_InnerJob$vtype	*vtype;
	_jc_polyglot_frontend_InnerJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_InnerJob$vtype _jc_polyglot_frontend_InnerJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_InnerJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_InnerJob$class_object;

#endif	/* _JC_polyglot_frontend_InnerJob_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/InnerJob.h <==
// public class polyglot.frontend.InnerJob

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9297314e3af3ddba polyglot_frontend_InnerJob
// @dep_class 42e687805b457724 polyglot_frontend_Job

// header file dependencies
// @dep_header polyglot_frontend_Job

#include "polyglot/frontend/Job.h"

#ifndef _JC_polyglot_frontend_InnerJob_H_
#define _JC_polyglot_frontend_InnerJob_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_JobExt$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_frontend_SourceJob$object;
struct _jc_polyglot_types_Context$object;

// Typedefs
typedef struct _jc_polyglot_frontend_InnerJob$sub_refs	_jc_polyglot_frontend_InnerJob$sub_refs;
typedef struct _jc_polyglot_frontend_InnerJob$sub_nonrefs	_jc_polyglot_frontend_InnerJob$sub_nonrefs;
typedef struct _jc_polyglot_frontend_InnerJob$refs	_jc_polyglot_frontend_InnerJob$refs;
typedef struct _jc_polyglot_frontend_InnerJob$nonrefs	_jc_polyglot_frontend_InnerJob$nonrefs;
typedef struct _jc_polyglot_frontend_InnerJob$object	_jc_polyglot_frontend_InnerJob$object;

typedef const struct _jc_polyglot_frontend_InnerJob$vmethods	_jc_polyglot_frontend_InnerJob$vmethods;
typedef const struct _jc_polyglot_frontend_InnerJob$vtable	_jc_polyglot_frontend_InnerJob$vtable;
typedef const struct _jc_polyglot_frontend_InnerJob$vtype	_jc_polyglot_frontend_InnerJob$vtype;

// Constructors
extern void _jc_polyglot_frontend_InnerJob$method$_init$01920a4a6e363988(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Pass__24ID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_frontend_InnerJob$method$context$4c5ebe4f0ff1c15f(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_frontend_InnerJob$method$getPasses$e5b4184d264aa29f(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_frontend_SourceJob$object *_jc_polyglot_frontend_InnerJob$method$sourceJob$2fc26d39f6f66cf4(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_InnerJob$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$context$4c5ebe4f0ff1c15f;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$getPasses$e5b4184d264aa29f;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$sourceJob$2fc26d39f6f66cf4;
extern _jc_method _jc_polyglot_frontend_InnerJob$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_InnerJob$vmethods {
	struct _jc_object	*(*context$4c5ebe4f0ff1c15f)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPasses$e5b4184d264aa29f)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_frontend_SourceJob$object	*(*sourceJob$2fc26d39f6f66cf4)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_InnerJob$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_InnerJob$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Job$vmethods	polyglot_frontend_Job;
	_jc_polyglot_frontend_InnerJob$vmethods	polyglot_frontend_InnerJob;
};

// Vtype
struct _jc_polyglot_frontend_InnerJob$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_InnerJob$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_InnerJob$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*outer;
	struct _jc_object	*context;
	struct _jc_polyglot_frontend_Pass__24ID$object	*begin;
	struct _jc_polyglot_frontend_Pass__24ID$object	*end;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_InnerJob$refs {
    _jc_polyglot_frontend_InnerJob$sub_refs	polyglot_frontend_InnerJob;
    _jc_polyglot_frontend_Job$sub_refs	polyglot_frontend_Job;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_InnerJob$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_InnerJob$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Job$sub_nonrefs	polyglot_frontend_Job;
    _jc_polyglot_frontend_InnerJob$sub_nonrefs	polyglot_frontend_InnerJob;
};

// Object instance structure
struct _jc_polyglot_frontend_InnerJob$object {
	_jc_polyglot_frontend_InnerJob$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_InnerJob$vtype	*vtype;
	_jc_polyglot_frontend_InnerJob$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_InnerJob$vtype _jc_polyglot_frontend_InnerJob$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_InnerJob, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_InnerJob$class_object;

#endif	/* _JC_polyglot_frontend_InnerJob_H_ */
